echo " \$ vim ${PROJECT}/debian/hello.1"
echo " ... hack, hack, hack, ..."
cp -f ${COMMONDIR}/${PROJECT}/debian/hello.1 ${PROJECT}/debian/hello.1
echo " \$ vim ${PROJECT}/debian/manpages"
echo " ... hack, hack, hack, ..."
cp -f ${COMMONDIR}/${PROJECT}/debian/manpages ${PROJECT}/debian/manpages
L "cat ${PROJECT}/debian/manpages"
